==> clinicedc-2.0.1.tar.gz: clinicedc-2.0.1/src/edc_model_admin/mixins/base_model_admin_redirect_mixin.py <==
from typing import Optional

from django.http.response import HttpResponseRedirect


class BaseModelAdminRedirectMixin:
    """Redirect on add, change, or delete."""

    def redirect_url(self, request, obj, post_url_continue=None) -> Optional[str]:
        pass

    def redirect_url_on_add(
        self, request, obj, post_url_continue=None
    ) -> Optional[str]:
        return self.redirect_url(request, obj, post_url_continue=post_url_continue)

    def redirect_url_on_change(
        self, request, obj, post_url_continue=None
    ) -> Optional[str]:
        return self.redirect_url(request, obj, post_url_continue=post_url_continue)

    def redirect_url_on_delete(self, request, obj_display, obj_id) -> Optional[str]:
        pass

    def response_add(self, request, obj, post_url_continue=None):
        redirect_url = None
        if "_addanother" not in request.POST and "_continue" not in request.POST:
            redirect_url = self.redirect_url_on_add(request, obj)
        if redirect_url:
            return HttpResponseRedirect(redirect_url)
        return super().response_add(request, obj, post_url_continue=post_url_continue)

    def response_change(self, request, obj):
        redirect_url = None
        if "_addanother" not in request.POST and "_continue" not in request.POST:
            redirect_url = self.redirect_url_on_change(request, obj)
        if redirect_url:
            return HttpResponseRedirect(redirect_url)
        return super().response_change(request, obj)

    def response_delete(self, request, obj_display, obj_id):
        redirect_url = self.redirect_url_on_delete(request, obj_display, obj_id)
        if redirect_url:
            return HttpResponseRedirect(redirect_url)
        return super().response_delete(request, obj_display, obj_id)

==> clinicedc-2.0.44.tar.gz: clinicedc-2.0.44/src/edc_model_admin/mixins/base_model_admin_redirect_mixin.py <==
from django.http.response import HttpResponseRedirect


class BaseModelAdminRedirectMixin:
    """Redirect on add, change, or delete."""

    def redirect_url(self, request, obj, post_url_continue=None) -> str | None:
        pass

    def redirect_url_on_add(self, request, obj, post_url_continue=None) -> str | None:
        return self.redirect_url(request, obj, post_url_continue=post_url_continue)

    def redirect_url_on_change(self, request, obj, post_url_continue=None) -> str | None:
        return self.redirect_url(request, obj, post_url_continue=post_url_continue)

    def redirect_url_on_delete(self, request, obj_display, obj_id) -> str | None:
        pass

    def response_add(self, request, obj, post_url_continue=None):
        redirect_url = None
        if "_addanother" not in request.POST and "_continue" not in request.POST:
            redirect_url = self.redirect_url_on_add(request, obj)
        if redirect_url:
            return HttpResponseRedirect(redirect_url)
        return super().response_add(request, obj, post_url_continue=post_url_continue)

    def response_change(self, request, obj):
        redirect_url = None
        if "_addanother" not in request.POST and "_continue" not in request.POST:
            redirect_url = self.redirect_url_on_change(request, obj)
        if redirect_url:
            return HttpResponseRedirect(redirect_url)
        return super().response_change(request, obj)

    def response_delete(self, request, obj_display, obj_id):
        redirect_url = self.redirect_url_on_delete(request, obj_display, obj_id)
        if redirect_url:
            return HttpResponseRedirect(redirect_url)
        return super().response_delete(request, obj_display, obj_id)
